//[mahjong-utils](../../../../index.md)/[mahjongutils.models](../../index.md)/[TileType](../index.md)/[M](index.md)

# M

[common]\
[M](index.md)

万

## Properties

| Name | Summary |
|---|---|
| [name](../../-wind/-north/index.md#-372974862%2FProperties%2F1581026887) | [common]<br>val [name](../../-wind/-north/index.md#-372974862%2FProperties%2F1581026887): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [ordinal](../../-wind/-north/index.md#-739389684%2FProperties%2F1581026887) | [common]<br>val [ordinal](../../-wind/-north/index.md#-739389684%2FProperties%2F1581026887): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
